<?php
// $Id: luceneapi_morelikethis.admin.inc,v 1.5 2009/08/30 16:55:57 cpliakas Exp $

/**
 * @file
 * Admin settings for Search Lucene MoreLikeThis.
 */

/**
 * Submit handler, clears cached priority queues.
 *
 * @param $form
 *   A FAPI array modeling the submitted form.
 * @param &$form_state
 *   An array containing the current state of the form.
 * @return
 *   NULL
 */
function luceneapi_morelikethis_admin_settings_submit($form, &$form_state) {
  cache_clear_all('luceneapi_morelikethis:', LUCENEAPI_CACHE_TABLE, TRUE);
}

/**
 * Administrative settings.
 *
 * @return
 *   An array of form elements.
 * @ingroup forms
 */
function luceneapi_morelikethis_admin_settings() {
  $form = array();

  // adds a description to the page
  $description = 'Search Lucene MoreLikeThis adds content recommendations via'
               .' the <em>Search Lucene MoreLikeThis</em> block, which can be'
               .' enabled at !link.  By comparing the text in the node to the'
               .' Lucene index, Search Lucene MoreLikeThis is able to pull out'
               .' the important words and execute a weighted search query to'
               .' find similar pieces of content.';

  $path = 'admin/build/block/list';
  $form['description']['#value'] = t($description, array('!link' => l($path, $path)));

  // Boost terms in query based on score.
  $form['search'] = array(
    '#type' => 'fieldset',
    '#title' => t('Search settings'),
    '#collapsible' => TRUE,
  );

  // common options for items that have a minimum
  $options = array(0 => t('No minimum'));

  $form['search']['luceneapi_morelikethis:num_displayed'] = array(
    '#type' => 'select',
    '#title' => t('Number of Recommendations'),
    '#default_value' => variable_get('luceneapi_morelikethis:num_displayed', 5),
    '#options' => drupal_map_assoc(range(1, 10)),
    '#description' => t('The number of recommendations displayed in the block.'),
  );

  $form['search']['luceneapi_morelikethis:empty_message'] = array(
    '#type' => 'textfield',
    '#title' => t('Message for no recommendations'),
    '#default_value' => variable_get(
      'luceneapi_morelikethis:empty_message',
      'No recommendations were found.'
    ),
    '#description' => t(
      'The message displayed in the block when no recommendations are returned.'
    ),
  );

  $form['filter'] = array(
    '#type' => 'fieldset',
    '#title' => t('Term filters'),
    '#collapsible' => TRUE,
  );

  $form['filter']['luceneapi_morelikethis:min_word_length'] = array(
    '#type' => 'select',
    '#title' => t('Minimum word length'),
    '#default_value' => variable_get('luceneapi_morelikethis:min_word_length', 3),
    '#options' => $options + drupal_map_assoc(range(1, 10)),
    '#description' => t('Ignore words less than this length.'),
  );

  $form['filter']['luceneapi_morelikethis:max_word_length'] = array(
    '#type' => 'select',
    '#title' => t('Maximum word length'),
    '#default_value' => variable_get('luceneapi_morelikethis:max_word_length', 0),
    '#options' => array(0 => t('No limit')) + drupal_map_assoc(range(3, 15)),
    '#description' => t('Ignore words greater than this length.'),
  );

  $form['filter']['luceneapi_morelikethis:min_term_freq'] = array(
    '#type' => 'select',
    '#title' => t('Minimum term frequency'),
    '#default_value' => variable_get('luceneapi_morelikethis:min_term_freq', 2),
    '#options' => $options + drupal_map_assoc(range(1, 20)),
    '#description' => t('Ignore terms with less than this frequency in the source text.'),
  );

  $form['filter']['luceneapi_morelikethis:min_doc_freq'] = array(
    '#type' => 'select',
    '#title' => t('Minimum document frequency'),
    '#default_value' => variable_get('luceneapi_morelikethis:min_doc_freq', 5),
    '#options' => $options + drupal_map_assoc(range(1, 20)),
    '#description' => t('Ignore words which do not occur in at least this many nodes.'),
  );

  $description = 'Return a Query with no more than this many terms.  Lowering'
               .' this setting will result in fewer recommendations, but it'
               .' will also improve the performance of the query.';

  $form['filter']['luceneapi_morelikethis:max_query_terms'] = array(
    '#type' => 'select',
    '#title' => t('Maximum terms to query'),
    '#default_value' => variable_get('luceneapi_morelikethis:max_query_terms', 25),
    '#options' => $options + drupal_map_assoc(range(0, 100, 5)),
    '#description' => t($description),
  );

  $form['fields'] = array(
    '#type' => 'fieldset',
    '#title' => t('Lucene fields'),
    '#collapsible' => TRUE,
    '#description' => t(
      'Select the fields that will be used when finding recommendations.'
    )
  );

  try {
    if ($index = luceneapi_index_open('luceneapi_node', $errstr)) {
      $options = drupal_map_assoc(luceneapi_index_fields_get($index, TRUE));
      $default = drupal_map_assoc(array('contents', 'title'));
    }
    else {
      throw new LuceneAPI_Exception($errstr);
    }
  }
  catch (LuceneAPI_Exception $e) {
    $options = array();
    $default = array();
    luceneapi_throw_error($e);
  }

  $form['fields']['luceneapi_morelikethis:fields'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Fields'),
    '#default_value' => variable_get('luceneapi_morelikethis:fields', $default),
    '#options' => $options,
    '#description' => t('Selecting no fields will use the default field.'),
  );

  return system_settings_form($form);
}
